@@ -30,34 +30,34 @@ class ObjectNotFound(Exception):
     pass
 
 
-## models
+# models
 def _build_filter(table="", day=None, room=None, track=None, event=None, **kwargs):
-        filterdata = []
-        wherestm = []
+    filterdata = []
+    wherestm = []
 
-        if table != "":
-            table = f"{table}."
+    if table != "":
+        table = f"{table}."
 
-        def __f(col, value):
-            if value is None:
-                wherestm.append(f"{table}{col} is null")
-            else:
-                wherestm.append(f"{table}{col} = ?")
-                filterdata.append(value)
+    def __f(col, value):
+        if value is None:
+            wherestm.append(f"{table}{col} is null")
+        else:
+            wherestm.append(f"{table}{col} = ?")
+            filterdata.append(value)
 
-        if day is not None:
-            __f("date", day.date)
-        if room is not None:
-            __f("room", room.name)
-        if track is not None:
-            __f("track", track.name)
-        if event is not None:
-            __f("id", event.id)
+    if day is not None:
+        __f("date", day.date)
+    if room is not None:
+        __f("room", room.name)
+    if track is not None:
+        __f("track", track.name)
+    if event is not None:
+        __f("id", event.id)
 
-        for k,v in kwargs.items():
-            __f(k, v)
+    for k, v in kwargs.items():
+        __f(k, v)
 
-        return (filterdata, wherestm)
+    return (filterdata, wherestm)
 
 
 class Conference:
@@ -74,7 +74,7 @@ class Conference:
         return self
 
     def get_map_links(self):
-        maps = [ l for l in self.metadata.get('links',[]) if l['title']=="Map" ]
+        maps = [link for link in self.metadata.get('links', []) if link['title'] == "Map"]
         print("Conference maps links:", maps)
         return maps
 
@@ -94,11 +94,11 @@ class Conference:
     @classmethod
     def all(cls):
         # from giggity menu
-        return [ cls()._init(s) for s in local.get_menu() ]
+        return [cls()._init(s) for s in local.get_menu()]
 
     @classmethod
     def by_url(cls, url):
-        ss = [ s for s in local.get_menu() if url in s['url'] ]
+        ss = [s for s in local.get_menu() if url in s['url']]
         if len(ss) == 0:
             return None
         return cls()._init(ss[0])
@@ -127,7 +127,7 @@ class Meta:
     def __init__(self):
         _c = local.getDb().execute("SELECT key, value FROM meta")
         _d = [(row['key'], self._fmtd_value(row['key'], row['value'])) for row in _c]
-        self._data = { 'last_update': 0 }
+        self._data = {'last_update': 0}
         self._data.update(dict(_d))
 
     def _fmtd_value(self, k, v):
@@ -172,7 +172,7 @@ class Meta:
 
     def to_json(self):
         """Export conference meta as json for user menu"""
-        return  {
+        return {
             "url": self.url,
             "title": self.title if self.title else "",
             "start": self.start.strftime("%Y-%m-%d"),
@@ -214,7 +214,6 @@ class Day:
             yield cls()._init(row)
 
 
-
 class Room:
     def _init(self, data):
         self.name = data['room']
@@ -274,7 +273,6 @@ class Track:
             return row[0]
 
 
-
 class Person:
     def _init(self, data):
         self.id = data['id']
@@ -348,14 +346,14 @@ class Event(GObject.GObject):
         return self
 
     def set_star(self, starred):
-        local.getDb().execute("UPDATE events SET starred=? WHERE id=?",(starred,self.id,))
+        local.getDb().execute("UPDATE events SET starred=? WHERE id=?", (starred, self.id,))
         local.getDb().commit()
         self.starred = starred
         self.emit('update')
         dbUpdateWatcher.emit('update')
 
     def set_notified(self, notified):
-        local.getDb().execute("UPDATE events SET notified=? WHERE id=?",(notified,self.id,))
+        local.getDb().execute("UPDATE events SET notified=? WHERE id=?", (notified, self.id,))
         local.getDb().commit()
         self.notified = notified
         self.emit('update')
@@ -373,7 +371,7 @@ class Event(GObject.GObject):
         return dt
 
     def persons(self):
-        #print("event", self.id, "persons()")
+        # print("event", self.id, "persons()")
         for row in local.getDb().execute(
                 """SELECT p.id, p.name FROM persons as p
                     LEFT JOIN event_person AS ep ON p.id = ep.person_id
@@ -416,7 +414,7 @@ class Event(GObject.GObject):
         return cls()._init(row)
 
     @classmethod
-    def filter(cls, day:Day = None, room:Room = None, track:Track = None, **kwargs):
+    def filter(cls, day: Day = None, room: Room = None, track: Track = None, **kwargs):
         filterdata, wherestm = _build_filter("events", day=day, room=room, track=track, **kwargs)
 
         query = """SELECT * FROM events
@@ -484,9 +482,6 @@ class Event(GObject.GObject):
         row = local.getDb().execute(resultcountquery, filterdata).fetchone()
         yield 0 if row is None else row['c']
 
-
         results = local.getDb().execute(query, filterdata)
         for row in results:
             yield cls()._init(row)
-
-
